==> Zephyrus-2.6.0.9986.tar.gz: Zephyrus-2.6.0.9986/Zephyrus/tests/boilerplate/FixTemplateTest.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: BuildBoilerplateTest.py 9866 2017-04-16 07:12:52Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2017-04-16 15:12:52 +0800 (週日, 16 四月 2017) $
# $Revision: 9866 $

import os
import sys
import unittest
import logging
import shutil

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)
handler = logging.StreamHandler()
handler.setFormatter(
    logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
logger.addHandler(handler)

HTML_DIR_PATH = os.path.abspath(
    os.path.join(__file__, '..', 'HtmlTemp'))

TEST_DIR_PATH = os.path.abspath(
    os.path.join(__file__, '..', 'TestHtml'))

TEMPLATES_DIR_PATH = os.path.abspath(
    os.path.join(__file__, '..', '..', 'templates'))

class FixTemplateTest(unittest.TestCase):
    def runBuildBoilerplate(self, origin, answer, 
                            dst=TEST_DIR_PATH, delete=True, rename=None):
        fileFrom = os.path.join(HTML_DIR_PATH, origin)
        if rename:
            copyTo = os.path.join(dst, rename)
        else:
            copyTo = os.path.join(dst, origin)
        answer = os.path.join(HTML_DIR_PATH, answer)
        shutil.copyfile(fileFrom, copyTo)
                
        os.system(
            "%s manage.py fix_template --overwrite=True" % sys.executable)

        with open(answer, 'r') as f:
            html1 = f.read()
        with open(copyTo, 'r') as f:
            html2 = f.read()
        
        self.assertEqual(html1, html2)
        if delete:
            os.remove(copyTo)

    def testFixTemplate(self):
        self.runBuildBoilerplate(
            'FixTemplate.html', 'FixTemplateAnswer.html', 
            dst=TEMPLATES_DIR_PATH)

if __name__ == '__main__':
    unittest.main()

==> Zephyrus-2.7.3.10201.tar.gz: Zephyrus-2.7.3.10201/Zephyrus/tests/boilerplate/FixTemplateTest.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: BuildBoilerplateTest.py 9866 2017-04-16 07:12:52Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2017-04-16 15:12:52 +0800 (週日, 16 四月 2017) $
# $Revision: 9866 $

import os
import sys
import unittest
import logging
import shutil

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)
handler = logging.StreamHandler()
handler.setFormatter(
    logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
logger.addHandler(handler)

HTML_DIR_PATH = os.path.abspath(
    os.path.join(__file__, '..', 'HtmlTemp'))

TEST_DIR_PATH = os.path.abspath(
    os.path.join(__file__, '..', 'TestHtml'))

TEMPLATES_DIR_PATH = os.path.abspath(
    os.path.join(__file__, '..', '..', 'templates'))

class FixTemplateTest(unittest.TestCase):
    def runBuildBoilerplate(self, origin, answer, 
                            dst=TEST_DIR_PATH, delete=True, rename=None):
        fileFrom = os.path.join(HTML_DIR_PATH, origin)
        if rename:
            copyTo = os.path.join(dst, rename)
        else:
            copyTo = os.path.join(dst, origin)
        answer = os.path.join(HTML_DIR_PATH, answer)
        shutil.copyfile(fileFrom, copyTo)
                
        os.system(
            "%s Manage.py fix_template --overwrite=True" % sys.executable)

        with open(answer, 'r') as f:
            html1 = f.read()
        with open(copyTo, 'r') as f:
            html2 = f.read()
        
        self.assertEqual(html1, html2)
        if delete:
            os.remove(copyTo)

    def testFixTemplate(self):
        self.runBuildBoilerplate(
            'FixTemplate.html', 'FixTemplateAnswer.html', 
            dst=TEMPLATES_DIR_PATH)

if __name__ == '__main__':
    unittest.main()
